## Experts start a new DAO

### Deploy DAO Contracts

```mermaid
sequenceDiagram

participant Admin
box DAO Core
participant Reputation
participant Forum
participant Bench
participant DAO
end 
box Additional DAO Contracts
participant Rollup
participant Proposals
participant Work
participant Onboarding
end

Admin ->> Reputation : Deploy
Admin ->> Forum : Deploy
Admin ->> Bench : Deploy
Admin ->> DAO : Deploy
DAO -->> Reputation : Registers DAO Contract
DAO -->> Forum : Registers DAO Contract
DAO -->> Bench : Registers DAO Contract
Admin ->> Rollup : Deploy
Rollup -->> DAO : References DAO Contract
Admin ->> Proposals : Deploy
Proposals -->> DAO : References DAO Contract
Admin ->> Work : Deploy
Work -->> DAO : References DAO Contract
Admin ->> Onboarding : Deploy
Onboarding -->> DAO : References DAO Contract

```

### Initialize DAO with a single member

```mermaid
sequenceDiagram

participant Expert
box DAO
participant Forum
participant Bench
end

Expert ->> Forum : Make an initial post
Expert ->> Bench : Initiate a Validation Pool, with a fee
Bench -->> Forum : VP targets initial post
Bench ->> Bench : VP passes automatically
Bench ->> Forum : Awards minted Reputation
Forum ->> Expert : Propagates Reputation
Bench ->> Expert : Distributes fee back to Expert
```

### Initialize DAO with multiple members

```mermaid
sequenceDiagram

participant Expert1
participant Expert2
participant Expert3
box DAO
participant Forum
participant Bench
end

Expert1 ->> Forum : Make an initial post, with Expert1, Expert2, and Expert3 as authors
Expert1 ->> Bench : Initiate a Validation Pool, with a fee
Bench -->> Forum : VP targets initial post
Bench ->> Bench : VP passes automatically
Bench ->> Forum : Awards minted Reputation
Forum ->> Expert1 : Propagates Reputation
Forum ->> Expert2 : Propagates Reputation
Forum ->> Expert3 : Propagates Reputation
Bench ->> Expert1 : Distributes fee among Experts
Bench ->> Expert2 : Distributes fee among Experts
Bench ->> Expert3 : Distributes fee among Experts
```

### Deploy Forum API

```mermaid
sequenceDiagram

participant Admin
participant api as Forum API
participant Matrix

```

### Deploy Matrix Widget

```mermaid
sequenceDiagram

participant e1 as Expert 1
participant e2 as Expert 2
participant matrix as Matrix
participant api as Forum API
participant widget as Matrix Widget

```

## New member joins a DAO

```mermaid
sequenceDiagram

participant Applicant
box DAO
participant Forum
participant Bench
participant Onboarding
end
participant Reviewer
participant Members as DAO Members

Reviewer ->> Onboarding : Stake availability
Applicant ->> Onboarding : Send onboarding request, with fee
Onboarding ->> Reviewer : Assign reviewer
Reviewer ->> Forum : Post recommendation
Reviewer ->> Onboarding : Submit recommendation
Onboarding ->> Bench : Initiate Validation Pool, including portion of onboarding fee
Bench -->> Forum : VP targets recommendation post
Members ->> Bench : Stake for/against VP
alt Recommendation VP passes
Bench ->> Forum : Awards minted Reputation
Forum ->> Reviewer : Propagates Reputation
Bench ->> Members : Distributes VP fee among Members
Onboarding ->> Forum : Make onboarding post on behalf of Applicant
Onboarding ->> Bench : Initiate Validation Pool, including remainder of onboarding fee
Members ->> Bench : Stake for/against VP
Bench -->> Forum : BP targets onboarding post
alt Onboarding VP passes
Bench ->> Forum : Awards minted Reputation
Forum ->> Applicant : Propagates Reputation
Bench ->> Members : Distributes VP fee among Members
end

end

```

## DAO member defines a new Work Contract

## Customer engages a Work Contract

## Contract triggers a dispute resolution process

## DAO changes the price of a Work Contract

## DAO upgrades the soft protocol

